#
# spec file for package python3-Twisted
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Twisted
Version:        16.3.0
Release:        1.1
Url:            http://twistedmatrix.com/
Summary:        An asynchronous networking framework written in Python
License:        MIT
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/T/Twisted/Twisted-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM -- https://twistedmatrix.com/trac/ticket/6280
Patch0:         lp1102685.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-devel >= 3.4
BuildRequires:  python3-pyOpenSSL
BuildRequires:  python3-pyserial
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
BuildRequires:  python3-zope.interface
Requires:       python3-pyOpenSSL
Requires:       python3-pyasn1
Requires:       python3-pycrypto
Requires:       python3-pyserial
Requires:       python3-zope.interface
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
An extensible framework for Python programming, with special focus
on event-based network programming and multiprotocol integration.

%package doc
Summary:        An asynchronous networking framework written in Python - Documentation
Group:          Development/Languages/Python

%description doc
An extensible framework for Python programming, with special focus
on event-based network programming and multiprotocol integration.

This package contains the documentation for python-Twisted

%prep
%setup -q -n Twisted-%{version}
%patch0 -p1
sed -i "1d" twisted/{mail/test/pop3testserver,trial/test/scripttest}.py

%build
CFLAGS="%{optflags}" python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot} --install-lib=%{python3_sitearch} --install-data=%{python3_sitearch}
find %{buildroot} -regex '.*\.[ch]' -exec rm {} ";" # Remove leftover C sources
install -dm0755 %{buildroot}/%{_mandir}/man1/
install -m0644 docs/*/man/*.1 %{buildroot}/%{_mandir}/man1/ # Install man pages
find docs -type f -print0 | xargs -0 chmod a-x # Fix doc-file dependency by removing x flags

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for p in trial twistd; do
# for p in cftp ckeygen conch mailmail pyhtmlizer tkconch trial twistd ; do
    mv %{buildroot}%{_bindir}/$p %{buildroot}%{_bindir}/$p-%{py3_ver}
    ln -s -f %{_sysconfdir}/alternatives/$p %{buildroot}%{_bindir}/$p
    # create a dummy target for /etc/alternatives/$p
    touch %{buildroot}%{_sysconfdir}/alternatives/$p
done

for p in cftp ckeygen conch mailmail pyhtmlizer tkconch trial twistd ; do
    gzip %{buildroot}%{_mandir}/man1/$p.1
    mv %{buildroot}%{_mandir}/man1/$p.1.gz %{buildroot}%{_mandir}/man1/$p-%{py3_ver}.1.gz
    ln -s -f %{_sysconfdir}/alternatives/$p.1.gz %{buildroot}%{_mandir}/man1/$p.1.gz
    # create a dummy target for /etc/alternatives/$p.1.gz
    touch %{buildroot}%{_sysconfdir}/alternatives/$p.1.gz
done

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/trial trial %{_bindir}/trial-%{py3_ver} 30 \
   --slave %{_mandir}/man1/trial.1.gz trial.1.gz %{_mandir}/man1/trial-%{py3_ver}.1.gz \
   --slave %{_mandir}/man1/cftp.1.gz cftp.1.gz %{_mandir}/man1/cftp-%{py3_ver}.1.gz \
   --slave %{_mandir}/man1/ckeygen.1.gz ckeygen.1.gz %{_mandir}/man1/ckeygen-%{py3_ver}.1.gz \
   --slave %{_mandir}/man1/conch.1.gz conch.1.gz %{_mandir}/man1/conch-%{py3_ver}.1.gz \
   --slave %{_mandir}/man1/mailmail.1.gz mailmail.1.gz %{_mandir}/man1/mailmail-%{py3_ver}.1.gz \
   --slave %{_mandir}/man1/pyhtmlizer.1.gz pyhtmlizer.1.gz %{_mandir}/man1/pyhtmlizer-%{py3_ver}.1.gz \
   --slave %{_mandir}/man1/tkconch.1.gz tkconch.1.gz %{_mandir}/man1/ctkconchftp-%{py3_ver}.1.gz \
   --slave %{_mandir}/man1/twistd.1.gz twistd.1.gz %{_mandir}/man1/twistd-%{py3_ver}.1.gz \
   --slave %{_bindir}/twistd twistd %{_bindir}/twistd-%{py3_ver}

# The remainder don't support Python 3.x yet:
#   --slave %{_bindir}/cftp cftp %{_bindir}/cftp-%{py3_ver} \
#   --slave %{_bindir}/ckeygen ckeygen %{_bindir}/ckeygen-%{py3_ver} \
#   --slave %{_bindir}/conch conch %{_bindir}/conch-%{py3_ver} \
#   --slave %{_bindir}/mailmail mailmail %{_bindir}/mailmail-%{py3_ver} \
#   --slave %{_bindir}/pyhtmlizer pyhtmlizer %{_bindir}/pyhtmlizer-%{py3_ver} \
#   --slave %{_bindir}/tkconch tkconch %{_bindir}/tkconch-%{py3_ver} \

%postun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove trial %{_bindir}/trial-%{py3_ver}
    %_sbindir/update-alternatives --remove twistd %{_bindir}/twistd-%{py3_ver}
fi

%files doc
%defattr(-,root,root,-)
%doc docs/*

%files
%defattr(-,root,root,-)
%doc CONTRIBUTING LICENSE NEWS README.rst
# %{_bindir}/cftp
# %{_bindir}/ckeygen
# %{_bindir}/conch
# %{_bindir}/mailmail
# %{_bindir}/pyhtmlizer
# %{_bindir}/tkconch
%{_bindir}/trial
%{_bindir}/twistd
# %{_bindir}/cftp-%{py3_ver}
# %{_bindir}/ckeygen-%{py3_ver}
# %{_bindir}/conch-%{py3_ver}
# %{_bindir}/mailmail-%{py3_ver}
# %{_bindir}/pyhtmlizer-%{py3_ver}
# %{_bindir}/tkconch-%{py3_ver}
%{_bindir}/trial-%{py3_ver}
%{_bindir}/twistd-%{py3_ver}
%{_mandir}/man1/cftp.1.gz
%{_mandir}/man1/ckeygen.1.gz
%{_mandir}/man1/conch.1.gz
%{_mandir}/man1/mailmail.1.gz
%{_mandir}/man1/pyhtmlizer.1.gz
%{_mandir}/man1/tkconch.1.gz
%{_mandir}/man1/trial.1.gz
%{_mandir}/man1/twistd.1.gz
%{_mandir}/man1/cftp-%{py3_ver}.1.gz
%{_mandir}/man1/ckeygen-%{py3_ver}.1.gz
%{_mandir}/man1/conch-%{py3_ver}.1.gz
%{_mandir}/man1/mailmail-%{py3_ver}.1.gz
%{_mandir}/man1/pyhtmlizer-%{py3_ver}.1.gz
%{_mandir}/man1/tkconch-%{py3_ver}.1.gz
%{_mandir}/man1/trial-%{py3_ver}.1.gz
%{_mandir}/man1/twistd-%{py3_ver}.1.gz
# %ghost %{_sysconfdir}/alternatives/cftp
# %ghost %{_sysconfdir}/alternatives/ckeygen
# %ghost %{_sysconfdir}/alternatives/conch
# %ghost %{_sysconfdir}/alternatives/mailmail
# %ghost %{_sysconfdir}/alternatives/pyhtmlizer
# %ghost %{_sysconfdir}/alternatives/tkconch
%ghost %{_sysconfdir}/alternatives/trial
%ghost %{_sysconfdir}/alternatives/twistd
%ghost %{_sysconfdir}/alternatives/cftp.1.gz
%ghost %{_sysconfdir}/alternatives/ckeygen.1.gz
%ghost %{_sysconfdir}/alternatives/conch.1.gz
%ghost %{_sysconfdir}/alternatives/mailmail.1.gz
%ghost %{_sysconfdir}/alternatives/pyhtmlizer.1.gz
%ghost %{_sysconfdir}/alternatives/tkconch.1.gz
%ghost %{_sysconfdir}/alternatives/trial.1.gz
%ghost %{_sysconfdir}/alternatives/twistd.1.gz
%{python3_sitearch}/*

%changelog
* Sat Jul  9 2016 arun@gmx.de
- specfile:
  * removed manhole, tap2dep, tap2rpm from for loop that creates man pages
- update to version 16.3.0:
  * Twisted Core
    + Defined a new interface, IProtocolNegotiationFactory, that can
    be implemented by IOpenSSLClientConnectionCreator or
    IOpenSSLServerConnectionCreator factories to allow them to offer
    protocols for negotiation using ALPN or NPN during the TLS
    handshake. (#8188)
    + twisted.trial.unittest.SynchronousTestCase.assertRegex is now
    available to provide Python 2.7 and Python 3
    compatibility. (#8372)
  * Improved Documentation
    + Development documentation has been updated to refer to Git
    instead of SVN. (#8335)
  * Deprecations and Removals
    + twisted.python.reflect's deprecated functions have been removed.
    This includes funcinfo (deprecated since Twisted 2.5),
    allYourBase and accumulateBases (deprecated since Twisted 11.0),
    getcurrent and isinst (deprecated since Twisted 14.0). (#8293)
    + twisted.scripts.tap2deb and twisted.scripts.tap2rpm (along with
    the associated executables), deprecated since Twisted 15.2, have
    now been removed. (#8326)
    + twisted.spread.ui has been removed. (#8329)
    + twisted.manhole -- not to be confused with manhole in Conch --
    has been removed. This includes the semi-functional Glade
    reactor, the manhole application, and the manhole-old twistd
    plugin. (#8330)
    + twisted.protocols.sip.DigestAuthorizer, BasicAuthorizer, and
    related functions have been removed. (#8445)
  * Other
    + #7229, #7826, #8290, #8323, #8331, #8336, #8341, #8344, #8345,
    [#8347], #8351, #8363, #8365, #8366, #8374, #8382, #8384, #8390,
    [#8395], #8396, #8398, #8399, #8400, #8401, #8403, #8404, #8405,
    [#8407], #8408, #8409, #8415, #8416, #8417, #8418, #8419, #8420,
    [#8427], #8433, #8436, #8461
  * Twisted Names
    + twisted.names.client.Resolver as well as all resolvers
    inheriting from twisted.names.common.ResolverBase can now
    understand DNS answers that come back in a different case than
    the query. Example: querying for www.google.com and the answer
    comes back with an A record for www.google.COM will now
    work. (#8343)
  * Twisted Web
    + twisted.web.http.HTTPChannel now implements ITransport. Along
    with this change, twisted.web.http.Request now directs all its
    writes to the HTTPChannel, rather than to the backing
    transport. This change is required for future HTTP/2
    work. (#8191)
    + twisted.web.http.HTTPChannel now has a HTTP/2 implementation
    which will be used if the transport has negotiated using it
    through ALPN/NPN (see #8188). (#8194)
    + twisted.web.client.Agent and twisted.web.client.ProxyAgent now
    add brackets to IPv6 literal addresses in the host header they
    send.  (#8369)
    + The HTTP server now correctly times connections out. (broken in
    16.2) (#8481)
    + twisted.web would previously dispatch pipelined requests
    simultaneously and queue the responses. This behaviour did not
    enforce any of the guarantees required by RFC 7230 or make it
    possible for users to enforce those requirements. For this
    reason, the parallel dispatch of requests has been
    removed. Pipelined requests are now processed serially. (#8320)
* Sat May 28 2016 arun@gmx.de
- update to version 16.2.0:
  * Twisted Core 16.2.0
    + twisted.protocols.haproxy.proxyEndpoint provides an endpoint
    that wraps any other stream server endpoint with the PROXY
    protocol that retains information about the original client
    connection handled by the proxy; this wrapper is also exposed
    via the string description prefix 'haproxy'; for example 'twistd
    web --port haproxy:tcp:8765'.  (#8203)
    + twisted.application.app.AppLogger (used by twistd) now uses the
    new logging system. (#8235)
    + twisted.application-using applications (trial, twistd, etc) now
    work with the --reactor option on Python 3. (#8299)
    + Failures are now logged by STDLibLogObserver. (#8316)
    + Deprecation documentation was extended to include a quick check
    list for developers. (#5645)
    + The Twisted Deprecation Policy is now documented in the Twisted
    Development Policy. (#8082)
    + The documentation examples for UDP now work on Python 3. (#8280)
    + Passing a factory that produces log observers that do not
    implement twisted.logger.ILogObserver or
    twisted.python.log.ILogObserver to
    twisted.application.app.AppLogger has been deprecated. This is
    primarily used by twistd's --logger option. Please use factories
    that produce log observers implementing
    twisted.logger.ILogObserver or the legacy
    twisted.python.log.ILogObserver. (#8235)
    + twisted.internet.qtreactor, a stub that imported the external
    qtreactor, has been removed. (#8288)
    + #6266, #8231, #8244, #8256, #8266, #8269, #8275, #8277, #8286,
    [#8291], #8292, #8304, #8315
  * Twisted Conch
    + #8279
  * Twisted Names
    + twisted.names.server is now ported to Python 3 (#8195)
    + twisted.names.authority and twisted.names.secondary have been
    ported to Python 3 (#8259)
  * Twisted Runner
    + twisted.runner.inetdtap and twisted.runner.inetdconf RPC support
    was deprecated as it was broken for a long time. (#8123)
  * Twisted Web
    + twisted.web.http.HTTPFactory's constructor now accepts a reactor
    argument, for explicit reactor selection. (#8246)
    + twisted.web.http.HTTPChannel.headerReceived now respond with 400
    and disconnect when a malformed header is received. (#8101)
    + twisted.web.http.Request once again has a reference to the
    HTTPFactory which created it, the absence of which was
    preventing log messages from being created.  (#8272)
    + twisted.web.http.HTTPChannel no longer processes requests that
    have invalid headers as the final header in their header
    block. (#8317)
    + twisted.web.client.HTTPClientFactory (and the getPage and
    downloadPage APIs) now timeouts correctly on TLS connections
    where the remote party is not responding on the
    connection. (#8318)
    + #8300
  * Twisted Words
    + twisted.words.protocols.msn, deprecated since Twisted 15.1, has
    been removed. (#8253)
    + twisted.words.protocols.oscar is deprecated. (#8260)
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Thu Apr 21 2016 arun@gmx.de
- update to version 16.1.1:
  * Twisted Web
    + twisted.web.http.Request once again has a reference to the
    HTTPFactory which created it, the absence of which was
    preventing log messages from being created.  (#8272)
* Fri Apr  8 2016 arun@gmx.de
- specfile:
  * doc seems do be now docs in tar-ball, changed accordingly
  * removed sed command that removes \r from two files. Files don't
    seem to have \r anymore. (Files also got moved to different dir in docs)
- update to version 16.1.0:
  * Twisted Core
    + twisted.application.internet.ClientService, a service that
    maintains a persistent outgoing endpoint-based connection; a
    replacement for ReconnectingClientFactory that uses modern APIs.
    (#4735)
    + Twisted now uses setuptools' sdist to build tarballs. (#7985)
    + Twisted is now compatible with OpenSSL 1.0.2f. (#8189)
    + changes from version - #4543, #8124, #8193, #8210, #8220, #8223,
    [#8226], #8242:
  * Twisted Conch
    + twisted.conch.checkers is now ported to Python 3. (#8225)
    + twisted.conch.telnet is now ported to Python 3. (#8228)
    + twisted.conch.manhole_ssh.ConchFactory (used by `twistd
    manhole`) no longer uses a hardcoded SSH server key, and will
    generate a persistent one, saving it in your user appdir. If you
    use ConchFactory, you will now need to provide your own SSH
    server key.  (#8229)
    + #8237, #8240
  * Twisted Web
    + twisted.web.http.Request.addCookie now supports both unicode and
    bytes arguments, with unicode arguments being encoded to UTF-8.
    (#8067)
    + twisted.web.util.DeferredResource no longer causes spurious
    "Unhandled error in Deferred" log messages. (#8192)
    + twisted.web.server.site.makeSession now generates an uid of type
    bytes on both Python 2 and 3. (#8215)
    + #8238
* Sat Mar 19 2016 arun@gmx.de
- update to version 16.0.0:
  * Twisted Core
    + todo parameter for IReporter.addExpectedSuccess and
    IReporter.addUnexpectedSuccess is no longer required. If not
    provided, a sensible default will be used instead. (#4811)
    + A new string endpoint type, "tls:", allows for properly-verified
    TLS (unlike "ssl:", always matching hostname resolution with
    certificate hostname verification) with faster IPv4/IPv6
    connections.  This comes with an accompanying function,
    twisted.internet.endpoints.wrapClientTLS, which can wrap an
    arbitrary client endpoint with client TLS. (#5642)
    + twisted.python.filepath.makedirs accepts an
    ignoreExistingDirectory flag which ignore the OSError raised by
    os.makedirs if requested directory already exists. (#5704)
    + twisted.protocols.amp has been ported to Python 3. (#6833)
    + twisted.internet.ssl.trustRootFromCertificates returns an object
    suitable for use as trustRoot= to
    twisted.internet.ssl.optionsForClientTLS that trusts multiple
    certificates. (#7671)
    + twisted.python.roots is now ported to Python 3. (#8131)
    + twisted.cred.strports has been ported to Python 3. (#8216)
    + Expected failures from standard library unittest no longer fail
    with Trial reporters. (#4811)
    + twisted.internet.endpoints.HostnameEndpoint.connect no longer
    fails with an AlreadyCalledError when the Deferred it returns is
    cancelled after all outgoing connection attempts have been made
    but none have yet succeeded or failed. (#8014)
    + twisted.internet.task.LoopingCall.withCount when run with
    internal of 0, now calls the countCallable with 1, regardless of
    the time passed between calls. (#8125)
    + twisted.internet.endpoints.serverFromString, when parsing a SSL
    strports definition, now gives the correct error message when an
    empty chain file is given. (#8222)
    + The Twisted Project has adopted the Contributor Covenant as its
    Code of Conduct. (#8173)
    + twisted.internet.task.LoopingCall.deferred is now
    deprecated. Use the deferred returned by
    twisted.internet.task.LoopingCall.start() (#8116)
    + twisted.internet.gtkreactor, the GTK+ 1 reactor deprecated since
    Twisted 10.1, has been removed. This does not affect the GTK2,
    GLib, GTK3, or GObject-Introspection reactors. (#8145)
    + twisted.protocols.mice, containing a Logitech MouseMan serial
    driver, has been deprecated. (#8148)
    + The __version__ attribute of former subprojects (conch, mail,
    names, news, pair, runner, web, and words) is deprecated in
    preference to the central twisted.__version__. (#8219)
    + #6842, #6978, #7668, #7791, #7881, #7943, #7944, #8050, #8104,
    [#8115], #8119, #8122, #8139, #8144, #8154, #8162, #8180, #8187,
    [#8220]
  * Twisted Conch
    + twisted.conch now uses cryptography instead of PyCrypto for its
    underlying crypto operations. (#7413)
    + twisted.conch.ssh.keys is now ported to Python 3. (#7998)
    + twisted.conch.ssh.channel.SSHChannel's getPeer and getHost
    methods now return an object which provides IAddress instead of
    an old- style tuple address. (#5999)
    + twisted.conch.endpoint.SSHCommandClientEndpoint, when
    authentication is delegated to an SSH agent, no longer leaves
    the agent connection opened when connection to the server is
    lost.  (#8138)
    + #7037, #7715, #8200, #8208
  * Twisted Web
    + twisted.web.http_headers._DictHeaders now correctly handles
    updating via keyword arguments in Python 3 (therefore
    twisted.web.http_headers is now fully ported to Python
    3). (#6082)
    + twisted.web.wsgi has been ported to Python 3. (#7993)
    + twisted.web.http_headers.Headers now accepts both Unicode and
    bytestring keys and values, encoding to iso-8859-1 and utf8
    respectively. (#8129)
    + twisted.web.vhost ported to Python 3. (#8132)
    + twisted.web.http.HTTPChannel now correctly handles non-ascii
    method name by returning 400. Previously non-ascii method name
    was causing unhandled exceptions. (#8102)
    + twisted.web.static.File on Python 3 now redirects paths to
    directories without a trailing slash, to a path with a trailing
    slash, as on Python 2. (#8169)
    + twisted.web.http.Request's headers and request_headers
    attributes, deprecated since Twisted 13.2, have been
    removed. (#8136)
    + twisted.web.static.addSlash is deprecated. (#8169)
    + #8140, #8182
* Tue Dec  1 2015 arun@gmx.de
- specfile:
  * README is now a .rst files
  * added CONTRIBUTING to %%doc
  * packaged twistd
- update to version 15.5.0:
  * Features
    + twisted.python.url is a new abstraction for URLs, supporting RFC
    3987 IRIs. (#5388)
    + twisted.python.logfile is now ported to Python 3. (#6749)
    + twisted.python.zippath has been ported to Python 3. (#6917)
    + twisted.internet.ssl.CertificateOptions and
    twisted.internet.ssl.optionsForClientTLS now take a
    acceptableProtocols parameter that enables negotiation of the next
    protocol to speak after the TLS handshake has completed. This field
    advertises protocols over both NPN and ALPN. Also added new
    INegotiated interface for TLS interfaces that support protocol
    negotiation. This interface adds a negotiatedProtocol property that
    reports what protocol, if any, was negotiated in the TLS handshake.
    (#7860)
    + twisted.python.urlpath.URLPath now operates correctly on Python 3,
    using bytes instead of strings, and introduces the fromBytes
    constructor to assist with creating them cross-version. (#7994)
    + twisted.application.strports is now ported to Python 3. (#8011)
    + twistd (the Twisted Daemon) is now ported to Python 3. (#8012)
    + Python 3.5 is now supported on POSIX platforms. (#8042)
    + twisted.internet.serialport is now ported on Python 3. (#8099)
  * Bugfixes
    + twisted.logger.formatEvent now can format an event if it was
    flattened (twisted.logger.eventAsJSON does this) and has text after
    the last replacement field. (#8003)
    + twisted.cred.checkers.FilePasswordDB now logs an error if the
    credentials db file does not exist, no longer raises an unhandled
    error. (#8028)
    + twisted.python.threadpool.ThreadPool now properly starts enough
    threads to do any work scheduled before ThreadPool.start() is
    called, such as when work is scheduled in the reactor via
    reactor.callInThread() before reactor.run(). (#8090)
  * Improved Documentation
    + Twisted Development test standard documentation now contain
    information about avoiding test data files. (#6535)
    + The documentation for twisted.internet.defer.DeferredSemaphore now
    describes the actual usage for limit and tokens instance
    attributes. (#8024)
  * Deprecations and Removals
    + twisted.python._initgroups, a C extension, has been removed and
    stdlib support is now always used instead. (#5861)
    + Python 2.6 is no longer supported. (#8017)
    + twisted.python.util.OrderedDict is now deprecated, and uses of it
    in Twisted are replaced with collections.OrderedDict. (#8051)
    + twisted.persisted.sob.load, twisted.persisted.sob.loadValueFromFile
    and twisted.persisted.sob.Persistent.save() are now deprecated when
    used with a passphrase. The encyption used by these methods are
    weak. (#8081)
    + twisted.internet.interfaces.IStreamClientEndpointStringParser has
    been removed and Twisted will no longer use parsers implementing
    this interface. (#8094)
  * Other
    + #5976, #6628, #6894, #6980, #7228, #7693, #7731, #7997, #8046,
    [#8054], #8056, #8060, #8063, #8064, #8068, #8072, #8091, #8095,
    [#8096], #8098, #8106
* Mon Oct 12 2015 toddrme2178@gmail.com
- Initial Python 3 version
* Mon Oct 12 2015 toddrme2178@gmail.com
- Implement update-alternatives in preparation for python 3 version.
* Sat Sep 12 2015 termim@gmail.com
- Update to version 15.4.0
  * add dependency on setuptools
  * lore removed
  * please see the NEWS file
* Tue Aug 11 2015 seife+obs@b1-systems.com
- change dep from python-asn1 to python-pyasn1 (renamed long ago)
* Thu Jun  4 2015 termim@gmail.com
- Wrong dependency rpm name, should be python-pycrypto
* Fri May 29 2015 termim@gmail.com
- Add missing dependencies on python-asn1 and python-Crypto
- Update to version 15.2.1:
  * twisted.logger now marks the `isError` key correctly on legacy
    events generated by writes to stderr. (#7903)
  * twisted.logger's documentation is now correctly listed in the table
    of contents. (#7904)
- Changes from version 15.2.0:
  * twisted.internet.process has now been ported to Python 3. (#5987)
  * twisted.cred.credentials is now ported to Python 3. (#6176)
  * twisted.trial.unittest.TestCase's assertEqual, assertTrue, and
    assertFalse methods now pass through the standard library's more
    informative failure messages. (#6306)
  * The new package twisted.logger provides a new, fully tested, and
    feature-rich logging framework. The old module twisted.python.log
    is now implemented using the new framework. The new logger HOWTO
    documents the new framework. (#6750)
  * twisted.python.modules is now ported to Python 3. (#7804)
  * twisted.python.filepath.FilePath now supports Unicode (text) paths.
    Like the os module, instantiating it with a Unicode path will
    return a Unicode-mode FilePath, instantiating with a bytes path
    will return a bytes-mode FilePath. (#7805)
  * twisted.internet.kqreactor is now ported to Python 3 (#7823)
  * twisted.internet.endpoints.ProcessEndpoint is now ported to Python
    3. (#7824)
  * twisted.python.filepath.FilePath now has asBytesMode and asTextMode
    methods which return a FilePath in the requested mode. (#7830)
  * twisted.python.components.proxyForInterface now creates method
    proxies that can be used with functools.wraps. (#7832)
  * The tls optional dependency will now also install the idna package
    to validate idna2008 names. (#7853)
  * Don't raise an exception if `DefaultLogObserver.emit()` gets an
    event with a message that raises when `repr()` is called on it.
    Specifically: use `textFromEventDict()` instead of a separate (and
    inferior) message rendering implementation. (#6569)
  * twisted.cred.credentials.DigestedCredentials incorrectly handled
    md5-sess hashing according to the RFC, which has now been fixed.
    (#7835)
  * Fixed an issue with twisted.internet.task.LoopingCall.withCount
    where sometimes the passed callable would be invoked with "0" when
    we got close to tricky floating point boundary conditions. (#7836)
  * twisted.internet.defer now properly works with the new logging
    system. (#7851)
  * Change `messages` key to `log_io` for events generated by
    `LoggingFile`. (#7852)
  * twisted.logger had literal characters in docstrings that are now
    quoted. (#7854)
  * twisted.logger now correctly formats a log event with a key named
    `message` when passed to a legacy log observer. (#7855)
  * twisted.internet.endpoints.HostnameEndpoint now uses getaddrinfo
    properly on Python 3.4 and above. (#7886)
  * Fix a typo in narrative documentation for logger (#7875)
  * tkunzip and tapconvert in twisted.scripts were deprecated in 11.0
    and 12.1 respectively, and are now removed. (#6747)
  * twisted.protocols.gps is deprecated in preference to
    twisted.positioning. (#6810)
  * twisted.scripts.tap2deb and twisted.scripts.tap2rpm are now
    deprecated. (#7682)
  * twisted.trial.reporter.TestResult and
    twisted.trial.reporter.Reporter contained deprecated methods (since
    8.0) which have now been removed. (#7815)
  * #6027, #7287, #7701, #7727, #7758, #7776, #7786, #7812, #7819,
    [#7831], #7838, #7865, #7866, #7869, #7872, #7877, #7878, #7885
  * twisted.conch.ssh.forwarding now supports local->remote forwarding
    of IPv6 (#7751)
  * twisted.mail.smtp.sendmail now uses ESMTP. It will
    opportunistically enable encryption and allow the use of
    authentication. (#7257)
  * twisted.web.static is now ported to Python 3. (#6177)
  * twisted.web.server.Site accepts requestFactory as constructor
    argument. (#7016)
  * twisted.web.util had some HTML generation functions deprecated
    since 12.1 that have now been removed. (#7828)
  * #6927, #7797, #7802, #7846
  * The resumeOffset argument to
    twisted.words.protocol.irc.DccFileReceive now works as it is
    documented. (#7775)
* Thu May  7 2015 jmatejek@suse.cz
- Version 15.1.0:
  * deprecated MSN protocol support
  * improved docs for Trial
  * removed deprecated UDPClient
  * twisted.web.static.File allows defining a custom resource for
    rendering forbidden pages.
  * minor bugfixes
* Sat Mar 14 2015 matwey.kornilov@gmail.com
- Version 15.0.0:
  + please, see NEWS file
- Update lp1102685.diff
* Thu Oct  2 2014 p.drouand@gmail.com
- Remove unprovided python-service_identity; it's not required in any
  way
* Thu Sep 18 2014 termim@gmail.com
- Update to version 14.0.2:
  + No significant changes have been made for this release.
- Update to version 14.0.1:
  + BrowserLikePolicyForHTTPS would always ignore the specified
    trustRoot and use the system trust root instead, which has been
    rectified. (#7647)
* Thu May 15 2014 hpj@urpla.net
- add dependency python-service_identity for testing purposes
* Wed May 14 2014 hpj@urpla.net
- Update to version 14.0.0:
  + too many changes to list here: check NEWS file
* Fri Dec  6 2013 speilicke@suse.com
- Add lp1102685.diff (bnc#853545): pygobject compatibility
- Update to version 13.2.0:
  + Twisted now includes a HostnameEndpoint implementation which uses IPv4 and
  IPv6 in parallel, speeding up the connection by using whichever connects first
  (the 'Happy Eyeballs'/RFC 6555 algorithm). (#4859)
  + Improved support for Cancellable Deferreds by kaizhang, our GSoC student.
    (#4320, #6532, #6572, #6639)
  + Improved Twisted.Mail documentation by shira, our Outreach Program for
    Women intern. (#6649, #6652)
  + twistd now waits for the application to start successfully before exiting
    after daemonization. (#823)
  + SSL server endpoint string descriptions now support the specification of
    chain certificates. (#6499)
  + Over 70 closed tickets since 13.1.0.
* Wed Sep 25 2013 p.drouand@gmail.com
- Update to version 13.1.0
  + Please read usr/share/doc/packages/python-Twisted/NEWS for more
    infos
* Sun Apr 14 2013 p.drouand@gmail.com
- Update to version 3.0.0
  + Features
  - The twisted.protocols.ftp.FTP server now treats "LIST -La", "LIST
  - al", and all other combinations of ordering and case of the "-l"
    and "-a" flags the same: by ignoring them rather than treating them
    as a pathname. (#1333)
  - twisted.python.log.FileLogObserver now uses `datetime.strftime` to
    format timestamps, adding support for microseconds and timezone
    offsets to the `timeFormat` string. (#3513)
  - trial now deterministically runs tests in the order in which they
    were specified on the command line, instead of quasi-randomly
    according to dictionary key ordering. (#5520)
  - Cooperator.running can be used to determine the current cooperator
    status. (#5937)
  - twisted.python.modules.PythonPath now implements `__contains__` to
    allow checking, by name, whether a particular module exists within
    it. (#6198)
  - twisted.application.internet.TimerService.stopService now waits for
    any currently running call to finish before firing its deferred.
    (#6290)
  + Bugfixes
  - twisted.protocols.ftp.FTP now recognizes all glob expressions
    supported by fnmatch. (#4181)
  - Constant values defined using twisted.python.constants can now be
    set as attributes of other classes without triggering an unhandled
    AttributeError from the constants implementation. (#5797)
  - Fixed problem where twisted.names.client.Resolver was not closing
    open file handles which can lead to an out of file descriptor error
    on PyPy. (#6216)
  - All reactors included in Twisted itself now gracefully handle a
    rare case involving delayed calls scheduled very far in the future.
    (#6259)
  - twisted.trial.reporter.Reporter._trimFrames correctly removes
    frames from twisted.internet.utils.runWithWarningsSuppressed again,
    after being broke in #6009. (#6282)
  + Improved Documentation
  - A new "Deploying Twisted with systemd" howto document which
    demonstrates how to start a Twisted service using systemd socket
    activation. (#5601)
  - New "Introduction to Deferreds" howto.  Old howto rebranded as
    reference documentation. (#6180)
  - "Components: Interfaces and Adapters" howto now uses
    zope.interface's decorator-based API. (#6269)
  + Deprecations and Removals
  - twisted.python.util.unsignedID and setIDFunction are deprecated
    now. (#5544)
  - twisted.python.zshcomp deprecated since 11.1.0 has now been
    removed. Shell tab-completion is now handled by
    twisted.python.usage. (#5767)
  - python.runtime.Platform.isWinNT is deprecated now. Use
    Platform.isWindows instead. (#5925)
  - twisted.trial.util.findObject, deprecated since Twisted 10.1.0, has
    been removed. (#6260)
* Fri Jan 11 2013 p.drouand@gmail.com
- Update to 12.3.0 version:
  * Features
  - The new -j flag to trial provides a trial runner supporting
  multiple worker processes on the local machine, for parallel
    testing. (#1784)
  - twisted.internet.task.react, a new function, provides a simple API
    for running the reactor until a single asynchronous function
    completes. (#3270)
  - twisted.protocols.ftp.FTP now handles FEAT and OPTS commands.
    (#4515)
  - trial now supports specifying a debugger other than pdb with the
  - -debugger command line flag. (#5794)
  - twisted.python.util.runWithWarningsSuppressed has been added; it
    runs a function with specified warning filters. (#5950)
  - trial's skipping feature is now implemented in a way compatible with the
    standard library unittest's runner. (#6006)
  - The setup3.py script is now provided to provisionally support
    building and installing an experimental, incomplete version of
    Twisted in a Python 3 environment. (#6040)
  - twisted.python.util.FancyStrMixin now supports arbitrary callables
    to format attribute values. (#6063)
  - Several new methods of twisted.trial.unittest.SynchronousTestCase
  - `successResultOf`, `failureResultOf`, and `assertNoResult` -
    have been added to make testing `Deferred`-using code easier.
    (#6105)
  * Bugfixes
  - twisted.protocols.basic.LineReceiver now does not hit the maximum
    stack recursion depth when the line and data mode is switched many
    times. (#3050)
  - twisted.protocols.ftp.FTPFileListProtocol fixed to support files
    with space characters in their name. (#4986)
  - gireactor and gtk3reactor no longer prevent gi.pygtkcompat from
    working, and likewise can load if gi.pygtkcompat has previously
    been enabled. (#5676)
  - gtk2reactor now works again on FreeBSD, and perhaps other platforms
    that were broken by gi interactions. (#5737)
  - gireactor now works with certain older versions of gi that are
    missing the threads_init() function. (#5790)
  - Fixed a bug where twisted.python.sendmsg would sometimes fail with
    obscure errors including "Message too long" or "Invalid argument"
    on some 64-bit platforms. (#5867)
  - twisted.internet.endpoints.TCP6ClientEndpoint now provides
    twisted.internet.interfaces.IStreamClientEndpoint (#5876)
  - twisted.internet.endpoints.AdoptedStreamServerEndpoint now provides
    twisted.internet.interfaces.IStreamServerEndpoint. (#5878)
  - Spawning subprocesses with PTYs now works on OS X 10.8. (#5880)
  - twisted.internet.test.test_sigchld no longer incorrectly fails when
    run after certain other tests. (#6161)
  - twisted.internet.test.test_gireactor no longer fails when using
    pygobject 3.4 and gtk 3.6 when X11 is unavailable. (#6170)
  - twisted/python/sendmsg.c no longer fails to build on OpenBSD.
    (#5907)
  * Deprecations and Removals
  - The minimum required version of zope.interface is now 3.6.0.
    (#5683)
  - twisted.internet.interfaces.IReactorArbitrary and
    twisted.application.internet.GenericServer and GenericClient,
    deprecated since Twisted 10.1, have been removed. (#5943)
  - twisted.internet.interfaces.IFinishableConsumer, deprecated since
    Twisted 11.1, has been removed. (#5944)
  - twisted.python.failure has removed all support for string
    exceptions. (#5948)
  - assertTrue, assertEqual, and the other free-functions in
    twisted.trial.unittest for writing assertions, deprecated since
    prior to Twisted 2.3, have been removed. (#5963)
  - Ports, connectors, wakers and other reactor-related types no longer
    log a nice warning when they are erroneously pickled. Pickling of
    such objects continues to be unsupported. (#5979)
  - twisted.python.components.Componentized no longer inherits from
    Versioned. (#5983)
  - twisted.protocols.basic.NetstringReceiver.sendString no longer
    accepts objects other than bytes; the removed behavior was
    deprecated in Twisted 10.0. (#6025)
  - The lookupRecord method of twisted.internet.interfaces.IResolver,
    never implemented or called by Twisted, has been removed. (#6091)
* Wed Sep 26 2012 msuman@gnome.org
- Update to version 12.2.0
  * Starting with the release after 12.2, Twisted will begin requiring
    zope.interface 3.6 (as part of Python 3 support).
  * Features
  - twisted.protocols.sip.MessageParser now handles multiline headers.
  - twisted.internet.endpoints now provides StandardIOEndpoint, a
    Standard I/O endpoint.
  - If a FTPCmdError occurs during twisted.protocols.ftp.FTP.ftp_RETR
    sending the file (i.e. it is raised by the IReadFile.send method it
    invokes), then it will use that to return an error to the client
    rather than necessarily sending a 426 CNX_CLOSED_TXFR_ABORTED error.
  - twisted.internet.interfaces.IReactorSocket.adoptStreamConnection is
    implemented by some reactors as a way to add an existing
    established connection to them.
  - twisted.internet.endpoints now provides TCP6ServerEndpoint, an IPv6
    TCP server endpoint.
  - twisted.internet.endpoints now provides TCP6ClientEndpoint, an IPv6
    TCP client endpoint.
  - twisted.internet.endpoints.serverFromString, the endpoint string
    description feature, can now be used to create IPv6 TCP servers.
  - twisted.internet.endpoints.serverFromString, the endpoint string
    description feature, can now be used to create servers that run on
    Standard I/O.
  - twisted.trial.unittest now offers SynchronousTestCase, a test case
    base class that provides usability improvements but not reactor-
    based testing features.
  * Bugfixes
  - twisted.internet.Process.signalProcess now catches ESRCH raised by
    os.kill call and raises ProcessExitedAlready instead.
  - TLSMemoryBIOProtocol (and therefore all SSL transports if pyOpenSSL
    >= 0.10) now provides the interfaces already provided by the
    underlying transport.
  * Deprecations and Removals
  - Python 2.5 is no longer supported.
  - The --extra option of trial, deprecated since 11.0, is removed now.
  - addPluginDir and getPluginDirs in twisted.python.util are
    deprecated now.
  - twisted.trial.runner.DocTestCase, deprecated in Twisted 8.0, has
    been removed.
  - startKeepingErrors, flushErrors, ignoreErrors, and clearIgnores in
    twisted.python.log (deprecated since Twisted 2.5) are removed now.
  - unzip, unzipIter, and countZipFileEntries in
    twisted.python.zipstream (deprecated in Twisted 11.0) are removed
    now.
  - twisted.test.time_helpers, deprecated since Twisted 10.0, has been
    removed.
  - twisted.web.static.FileTransfer, deprecated since 9.0, is removed
    now. Use a subclass of StaticProducer instead.
  - ErrorPage, NoResource and ForbiddenResource in twisted.web.error
    were deprecated since 9.0 and are removed now.
  - twisted.web.google, deprecated since Twisted 11.1, is removed now.
* Wed Sep 26 2012 msuman@gnome.org
- Update to version 12.1.0
  * Features
  - The kqueue reactor has been revived.
  - twisted.python.filepath now provides IFilePath, an interface for
    file path objects.
  - New gtk3 and gobject-introspection reactors have been added.
  - gtk and glib reactors now run I/O and scheduled events with lower
    priority, to ensure the UI stays responsive.
  - IReactorTCP.connectTCP() can now accept IPv6 address literals
    (although not hostnames) in order to support connecting to IPv6
    hosts.
  - twisted.internet.interfaces.IReactorSocket, a new interface, is now
    supported by some reactors to listen on sockets set up by external
    software (eg systemd or launchd).
  - twisted.internet.endpoints.clientFromString now also supports
    strings in the form of tcp:example.com:80 and ssl:example.com:4321
  - twisted.python.constants.Flags now provides a way to define
    collections of flags for bitvector-type uses.
  - The epoll(7)-based reactor is now the default reactor on Linux.
  - twisted.python.runtime.platform.isLinux can be used to check if
    Twisted is running on Linux.
  - twisted.internet.endpoints.serverFromString now recognizes a
    "systemd" endpoint type, for listening on a server port inherited
    from systemd.
  - Connections created using twisted.internet.interfaces.IReactorUNIX
    now support sending and receiving file descriptors between
    different processes.
  - twisted.internet.endpoints.clientFromString now supports UNIX
    client endpoint strings with the path argument specified like
    "unix:/foo/bar" in addition to the old style, "unix:path=/foo/bar".
  - twisted.protocols.amp.Descriptor is a new AMP argument type which
    supports passing file descriptors as AMP command arguments over
    UNIX connections.
  - twisted.web.client.Agent and ProxyAgent now support persistent
    connections.
  - Added twisted.web.template.renderElement, a function which renders
    an Element to a response.
  - twisted.web.client.HTTPConnectionPool now ensures that failed
    queries on persistent connections are retried, when possible.
  - twisted.web.template.XMLFile now supports FilePath objects.
  - twisted.web.template.renderElement takes a doctype keyword
    argument, which will be written as the first line of the response,
    defaulting to the HTML5 doctype.
  * Bugfixes
  - twisted.internet.abstract.FileDescriptor implements
    twisted.internet.interfaces.IPushProducer instead of
    twisted.internet.interfaces.IProducer.
    twisted.internet.iocpreactor.abstract.FileHandle implements
    twisted.internet.interfaces.IPushProducer instead of
    twisted.internet.interfaces.IProducer.
  - The epoll reactor now supports reading/writing to regular files on
    stdin/stdout.
  - Calling .cancel() on any Twisted-provided client endpoint
    (TCP4ClientEndpoint, UNIXClientEndpoint, SSL4ClientEndpoint) now
    works as documented, rather than logging an AlreadyCalledError.
  - A leak of OVERLAPPED structures in some IOCP error cases has been
    fixed.
  - twisted.internet._pollingfile._PollableWritePipe now checks for
    outgoing unicode data in write() and writeSequence() instead of
    checkWork().
  - twisted.web.util.formatFailure now quotes all data in its output to
    avoid it being mistakenly interpreted as markup.
  - twisted.web.distrib now lets distributed servers set the response
    message.
  * Improved Documentation
  - "Working from Twisted's Subversion repository" links to UQDS and
    Combinator are now updated.
  - Added tkinterdemo.py, an example of Tkinter integration.
  * Deprecations and Removals
  - The 'unsigned' flag to twisted.scripts.tap2rpm.MyOptions is now
    deprecated.
  - Removed the unreachable _fileUrandom method from
    twisted.python.randbytes.RandomFactory.
  - twisted.persisted.journal is removed, deprecated since Twisted
    11.0.
  - Support for pyOpenSSL 0.9 and older is now deprecated.  pyOpenSSL
    0.10 or newer will soon be required in order to use Twisted's SSL
    features.
  - backwardsCompatImplements and fixClassImplements are removed from
    twisted.python.components, deprecated in 2006.
  - twisted.python.reflect.macro was removed, deprecated since Twisted
    8.2.
  - twisted.python.text.docstringLStrip, deprecated since Twisted
    10.2.0, has been removed
  - Removed the deprecated dispatch and dispatchWithCallback methods
    from twisted.python.threadpool.ThreadPool (deprecated since 8.0)
  - twisted.scripts.tapconvert is now deprecated.
  - twisted.python.reflect's Settable, AccessorType, PropertyAccessor,
    Accessor, OriginalAccessor and Summer are now deprecated.
  - twisted.python.threadpool.ThreadSafeList (deprecated in 10.1) is
    removed.
  - twisted.application.app.initialLog, deprecated since Twisted 8.2.0,
    has been removed.
  - twisted.spread.refpath was deleted, deprecated since Twisted 9.0.
  - twisted.python.otp, deprecated since 9.0, is removed.
  - Removed `dsu`, `moduleMovedForSplit`, and `dict` from
    twisted.python.util (deprecated since 10.2)
  - PHP3Script and PHPScript were removed from twisted.web.twcgi,
    deprecated since 10.1. Use twcgi.FilteredScript instead.
  - twisted.web.template.XMLFile's support for file objects and
    filenames is now deprecated.  Use the new support for FilePath
    objects.
  - twisted.web.server.date_time_string and
    twisted.web.server.string_date_time are now deprecated in favor of
    twisted.web.http.datetimeToString and twisted.web.
    http.stringToDatetime
* Mon Feb 20 2012 saschpe@suse.de
- Changes file cleanup
* Sun Feb 19 2012 termim@gmail.com
- Update to version 0.12
  * Features
  - The interface argument to IReactorTCP.listenTCP may now be an IPv6
    address literal, allowing the creation of IPv6 TCP servers.
  - twisted.python.constants.Names now provides a way to define
    collections of named constants, similar to the "enum type" feature
    of C or Java.
  - twisted.python.constants.Values now provides a way to define
    collections of named constants with arbitrary values.
  * Bugfixes
  - Fixed an obscure case where connectionLost wasn't called on the
    protocol when using half-close.
  - UDP ports handle socket errors better on Windows.
  - When idle, the gtk2 and glib2 reactors no longer wake up 10 times a
    second.
  - Prevent a rare situation involving TLS transports, where a producer
    may be erroneously left unpaused.
  - twisted.internet.iocpreactor.iocpsupport now has fewer 64-bit
    compile warnings.
  - The GTK2 reactor is now more responsive on Windows.
  - TLS transports now correctly handle producer registration after the
    connection has been lost.
  - twisted.protocols.htb.Bucket now empties properly with a non-zero
    drip rate.
  - IReactorSSL and ITCPTransport.startTLS now synchronously propagate
    errors from the getContext method of context factories, instead of
    being capturing them and logging them as unhandled.
  * Improved Documentation
  - The multicast documentation has been expanded.
  - twisted.internet.defer.Deferred now documents more return values.
  - Show a better starting page at
    http://twistedmatrix.com/documents/current
  * Deprecations and Removals
  - Remove the deprecated module twisted.enterprise.reflector.
  - Removed the deprecated module twisted.enterprise.row.
  - Remove the deprecated module twisted.enterprise.sqlreflector.
  - Removed the deprecated module twisted.enterprise.util, as well as
    twisted.enterprise.adbapi.safe.
  - Python 2.4 is no longer supported on any platform.
  - Removed printTraceback and noOperation from twisted.spread.pb,
    deprecated since Twisted 8.2.
* Tue Sep 20 2011 saschpe@suse.de
- Changed BuildRequires python-zopeinterface to python-zope.interface,
  it got renamed
* Tue Sep  6 2011 saschpe@suse.de
- Changed Buildrequires 'python-serial' to 'python-pyserial'
* Fri Sep  2 2011 saschpe@suse.de
- Update to version 0.11:
  * Features:
  - The twistd man page now has a SIGNALS section.
  - reactor.spawnProcess now will not emit a PotentialZombieWarning when called
    before reactor.run, and there will be no potential for zombie processes in this case.
  - High-throughput applications based on Perspective Broker should now run
    noticably faster thanks to the use of a more efficient decoding function
    in Twisted Spread.
  - Documentation for trac-post-commit-hook functionality in svn-dev policy.
  - twisted.protocols.socks.SOCKSv4 now supports the SOCKSv4a protocol.
  - Trial can now output test results according to the subunit protocol, as
    long as Subunit is installed.
  - twisted.protocols.amp now provides a ListOf argument type which can be
    composed with some other argument types to create a zero or more element
    sequence of that type.
  - If returnValue is invoked outside of a function decorated with
    @inlineCallbacks, but causes a function thusly decorated to exit, a
    DeprecationWarning will be emitted explaining this potentially confusing
    behavior. In a future release, this will cause an exception.
  - twisted.python.logfile.BaseLogFile now has a reopen method allowing to
    use an external logrotate mechanism.
  * Bugfixes:
  - FTP.ftp_NLST now handles requests on invalid paths in a way consistent
    with RFC 959.
  - twisted.python.util.initgroups now calls the low-level C initgroups by
    default if available: the python version can create lots of I/O with certain
    authentication setup to retrieve all the necessary information.
  - startLogging now does nothing on subsequent invocations, thus fixing a
    terrible infinite recursion bug that's only on edge case.
  - Stringify non-string data to NetstringReceiver.sendString before
    calculating the length so that the calculated length is equal to the actual
    length of the transported data.
  - twisted.python.win32.cmdLineQuote now correctly quotes empty strings arguments.
  - Change the behavior of the Gtk2Reactor to register only one source watch for
    each file descriptor, instead of one for reading and one for writing. In
    particular, it fixes a bug with Glib under Windows where we failed to notify
    when a client is connected.
  - Twisted Trial no longer crashes if it can't remove an old _trial_temp directory.
  - The optional _c_urlarg extension now handles unquote("") correctly on
    platforms where malloc(0) returns NULL, such as AIX. It also compiles with less warnings.
  - On POSIX, child processes created with reactor.spawnProcess will no longer
    automatically ignore the signals which the parent process has set to be ignored.
  - All SOCKSv4a tests now use a dummy reactor with a deterministic resolve method.
  - Prevent extraneous server, date and content-type headers in proxy responses.
  * Deprecations and Removals:
  - twisted.internet.error.PotentialZombieWarning is now deprecated.
  - twisted.test.time_helpers is now deprecated.
  - The deprecated connectUDP method of IReactorUDP has now been removed.
  - twisted.trial.unittest.TestCase now ignores the previously deprecated
    setUpClass and tearDownClass methods.
- Renamed to python-Twisted from python-twisted
* Wed Aug 31 2011 coolo@suse.com
- remove unreferenced patch
* Wed Aug 31 2011 coolo@suse.com
- do not package executable docs
* Tue Aug 30 2011 andrea.turrini@gmail.com
- Standardized "Authors:" format in descriptions of python-twisted.spec
* Tue Nov 30 2010 alexandre@exatati.com.br
- Update to 10.2.0:
  - Huge ChangeLog, please check NEWS file or
    http://twistedmatrix.com/trac/browser/tags/releases/twisted-10.2.0/NEWS?format=raw.
* Mon Jul  5 2010 alexandre@exatati.com.br
- Update to 10.1.0:
  - Huge ChangeLog, please check NEWS file.
* Fri Apr 30 2010 alexandre@exatati.com.br
- Update to 10.0.0;
- Spec file cleaned with spec-cleaner.
* Mon Feb 23 2009 matejcik@suse.cz
- merged a patch that was not included in 8.2.0 and contains
  more python 2.6 compatibility fixes
* Fri Feb 13 2009 matejcik@suse.cz
- update to 8.2.0
  * python 2.6 compatible changes
  * many bugfixes and minor features in all submodules
- remerged all individual subpackages into one single package
  * reasons: easier maintenance, upstream releases the whole thing
    in sync, no additional dependencies for main package, negligible
    impact on package size
* Mon Apr  7 2008 matejcik@suse.cz
- update to 8.0.1 (2.6.0 actually)
  * new versioning scheme, 8.0.1 is second release in 2008
  * massively improved IOCP reactor
  * improvements to Trial
  * huge number of minor features and bugfixes
* Thu Aug  2 2007 jmatejek@suse.cz
- update to 2.5.0
  * support for Asynchronous Messaging Protocol
  * epoll-based reactor
  * twistd now accepts subcommands instead of 'mktap'
  * support for python2.5
  * support for inline callbacks (via 'yield')
  * many bugfixes and minor features
* Thu Nov  9 2006 jmatejek@suse.cz
- fixed ComponentDeprecationWarnings in twisted's class Credentials
* Mon Oct 23 2006 jmatejek@suse.cz
- update to 2.4.0
  - no longer works with py 2.2
  - many improvements on Trial
  - backwards compatibility layers disabled by default
  - improved and extended API documentation
  - new protocols
  - many bugfixes
- fixed some 64bit problems from PEP353 change
- removed nonsensical "???" from one of the testfiles
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan  5 2006 jmatejek@suse.cz
- update to 2.1.0
* Thu Oct  6 2005 matejcik@suse.cz
- update to 2.0.1
* Thu Apr 14 2005 mcihar@suse.cz
- update to 2.0.0
* Tue Feb  8 2005 mcihar@suse.cz
- fix permissions
* Tue Nov 30 2004 mcihar@suse.cz
- spec file cleanup
* Wed Aug 25 2004 garloff@suse.de
- Initial creation of package python-twisted.
